<?php

/*-----------------------------------------------------------------------------------*/
/* STYLES AND SCRIPTS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sveva_enqueue_scripts')) {

	function sveva_enqueue_scripts() {

		wp_deregister_style ('suevafree-style' );
		wp_deregister_style ('suevafree-header_layout_1');
		
		if ( !suevafree_setting( 'sveva_header_layout') || suevafree_setting( 'sveva_header_layout') == 'sveva_header_layout' ) :
		
			wp_enqueue_style( 'sveva-header_layout', get_stylesheet_directory_uri() . '/assets/css/sveva-header-layout.css' );
		
		else:
		
			$header_layout = str_replace('suevafree_', '', suevafree_setting( 'sveva_header_layout'));
			wp_enqueue_style( 'suevafree-' . $header_layout , get_template_directory_uri() . '/assets/css/header/' . $header_layout . '.css' );
		
		endif;

		if ( !get_theme_mod('suevafree_skin') )
			wp_enqueue_style( 'sveva-orange' , get_template_directory_uri() . '/assets/skins/orange.css' ); 

		if ( get_theme_mod('suevafree_skin') ) : 
		
			wp_deregister_style( 'suevafree-' . get_theme_mod('suevafree_skin')); 
			wp_enqueue_style( 'sveva-' . get_theme_mod('suevafree_skin') , get_template_directory_uri() . '/assets/skins/' . get_theme_mod('suevafree_skin') . '.css' ); 
		
		endif;

	}
	
	add_action( 'wp_enqueue_scripts', 'sveva_enqueue_scripts', 99 );

}

/*-----------------------------------------------------------------------------------*/
/* SETUP */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sveva_theme_setup')) {

	function sveva_theme_setup() {

		load_child_theme_textdomain( 'sveva', get_stylesheet_directory() . '/languages' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'template-part/header-layout.php' );
		
		register_default_headers( array(
			'default-image' => array(
				'url'           => get_stylesheet_directory_uri() . '/assets/images/header.jpg',
				'thumbnail_url' => get_stylesheet_directory_uri() . '/assets/images/resized-header.jpg',
				'description'   => __( 'Default image', 'sveva' )
			),
		));

		add_theme_support( 'custom-header', array( 
			'width'         => 1920,
			'height'        => 492,
			'default-image' => get_stylesheet_directory_uri() . '/assets/images/header.jpg',
			'header-text' 	=> false
		));

		if ( !suevafree_setting('suevafree_thumb_triangle') )
			set_theme_mod( 'suevafree_thumb_triangle', 'on' );
			
		if ( !suevafree_setting('suevafree_thumb_hover') )
			set_theme_mod( 'suevafree_thumb_hover', 'on' );
			
		if ( !suevafree_setting('suevafree_disable_box_shadow') )
			set_theme_mod( 'suevafree_disable_box_shadow', 'on' );

		if ( !suevafree_setting('suevafree_post_format_layout') )
			set_theme_mod( 'suevafree_post_format_layout', 'on' );

		if ( !suevafree_setting('suevafree_post_details_layout') )
			set_theme_mod( 'suevafree_post_details_layout', 'suevafree_before_content_2' );

		if ( !suevafree_setting('suevafree_page_details_layout') )
			set_theme_mod( 'suevafree_page_details_layout', 'suevafree_before_content_3' );

		if ( !suevafree_setting('suevafree_sidebar_layout') )
			set_theme_mod( 'suevafree_sidebar_layout', 'sneak' );

		if ( !suevafree_setting('suevafree_footer_layout') )
			set_theme_mod( 'suevafree_footer_layout', 'footer_layout_3' );

	}

	add_action( 'after_setup_theme', 'sveva_theme_setup' );

}

/*-----------------------------------------------------------------------------------*/
/* CSS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sveva_custom_css')) {

	function sveva_custom_css() { 

		$css = '';
		
		if ( get_theme_mod('sveva_header_bottom_padding'))
			$css .= "#header.header-9 { padding-bottom: ". esc_html(get_theme_mod('sveva_header_bottom_padding'))."; }"; 

		if ( get_header_image() ) :
				
			$css .=  '
				#header.header-9 { 
					background-image: url('.esc_html(get_header_image()).');
					-webkit-background-size: cover !important;
					-moz-background-size: cover !important;
					-o-background-size: cover !important;
					background-size: cover !important;
				}'; 
		
		endif;
		
		if ( !get_theme_mod('sveva_header_attachment') || get_theme_mod('sveva_header_attachment') == 'fixed' ) :
			
			$css .=  '
				#header.header-9 { 
					background-attachment: fixed;
				}'; 

		endif;

		wp_add_inline_style( 'suevafree-template', $css );
		
	}

	add_action('wp_enqueue_scripts', 'sveva_custom_css', 999);

}

/*-----------------------------------------------------------------------------------*/
/* CUSTOMIZE */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sveva_customize_register')) {

	function sveva_customize_register( $wp_customize ) {
	
		$wp_customize->remove_setting( 'suevafree_header_layout');
		$wp_customize->remove_control( 'suevafree_header_layout');

		$wp_customize->add_setting( 'sveva_header_bottom_padding', array(
			'default' => '250px',
			'sanitize_callback' => 'sanitize_text_field',
		));

		$wp_customize->add_control( 'sveva_header_bottom_padding' , array(
			'priority' => 10,
			'type' => 'text',
			'section' => 'header_image',
			'label' => esc_html__('Header bottom padding', 'sveva'),
			'description' => esc_html__('Set the bottom padding for the header', 'sveva'),
		));

		$wp_customize->add_setting( 'sveva_header_attachment', array(
			'default' => 'fixed',
			'sanitize_callback' => 'sveva_select_sanitize',
		));

		$wp_customize->add_control( 'sveva_header_attachment' , array(
									
			'type' => 'select',
			'section' => 'header_image',
			'priority' => 11,
			'label' => esc_html__('Header Layout','sveva'),
			'description' => esc_html__('Header Layout','sveva'),
			'choices'  => array (
				'initial' => esc_html__( 'Initial', 'sveva'),
				'fixed' => esc_html__( 'Scroll with Page', 'sveva'),
			),
												
		));

		$wp_customize->add_setting( 'sveva_header_layout', array(
			'default' => 'sveva_header_layout',
			'sanitize_callback' => 'sveva_select_sanitize',
		));

		$wp_customize->add_control( 'sveva_header_layout' , array(
									
			'type' => 'select',
			'section' => 'layouts_section',
			'priority' => 1,
			'label' => esc_html__('Header Layout','sveva'),
			'description' => esc_html__('Header Layout','sveva'),
			'choices'  => array (
				'sveva_header_layout' => esc_html__( 'Sveva Header Layout',   'sveva'),
				'suevafree_header_layout_1' => esc_html__( 'SuevaFree Header Layout 1', 'sveva'),
				'suevafree_header_layout_2' => esc_html__( 'SuevaFree Header Layout 2', 'sveva'),
				'suevafree_header_layout_3' => esc_html__( 'SuevaFree Header Layout 3', 'sveva'),
				'suevafree_header_layout_4' => esc_html__( 'SuevaFree Header Layout 4', 'sveva'),
				'suevafree_header_layout_5' => esc_html__( 'SuevaFree Header Layout 5', 'sveva'),
			),
												
		));

		function sveva_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}

	}
	
	add_action( 'customize_register', 'sveva_customize_register', 11 );

}

?>